@@ -9,6 +9,8 @@ use base 'Mojo::Server';
 
 use IO::Poll 'POLLIN';
 
+use constant CHUNK_SIZE => $ENV{MOJO_CHUNK_SIZE} || 4096;
+
 __PACKAGE__->attr('nph', default => 0);
 
 # Lisa, you're a Buddhist, so you believe in reincarnation.
@@ -33,7 +35,7 @@ sub run {
         $poll->poll(0);
         my @readers = $poll->handles(POLLIN);
         last unless @readers;
-        my $read = STDIN->sysread(my $buffer, 4096, 0);
+        my $read = STDIN->sysread(my $buffer, CHUNK_SIZE, 0);
         $req->parse($buffer);
     }
 
