@@ -20,6 +20,7 @@ __PACKAGE__->attr(
             jpeg => 'image/jpeg',
             jpg  => 'image/jpeg',
             js   => 'application/x-javascript',
+            json => 'application/json',
             png  => 'image/png',
             tar  => 'application/x-tar',
             txt  => 'text/plain',
@@ -61,6 +62,8 @@ L<MojoX::Types> is a container for MIME types.
 
 =head2 ATTRIBUTES
 
+L<MojoX::Types> implements the following attributes.
+
 =head2 C<types>
 
     my $map = $types->types;
